summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/options.h
diff options
context:
space:
mode:
authorChris Campbell <chriscampbell89@gmail.com>2013-12-09 12:41:17 +0000
committerChris Campbell <chriscampbell89@gmail.com>2013-12-10 15:37:22 +0000
commit9ff65a6a82d6c134e5ba0459042672e51d0cf3b5 (patch)
tree28aea7cf8bd59c2c5dafe4d877586c8fc901444f /crawl-ref/source/options.h
parent8fe954617de510e6e1666c5bf5f024c737d2ca4c (diff)
downloadcrawl-ref-9ff65a6a82d6c134e5ba0459042672e51d0cf3b5.tar.gz
crawl-ref-9ff65a6a82d6c134e5ba0459042672e51d0cf3b5.zip
Fix spelling of "targeting" (#7837)
See Mantis for discussion.
Diffstat (limited to 'crawl-ref/source/options.h')
-rw-r--r--crawl-ref/source/options.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/crawl-ref/source/options.h b/crawl-ref/source/options.h
index 40ff7093fe..53e39dc227 100644
--- a/crawl-ref/source/options.h
+++ b/crawl-ref/source/options.h
@@ -131,7 +131,7 @@ public:
int msg_max_height;
bool mlist_allow_alternate_layout;
bool messages_at_top;
- bool mlist_targetting;
+ bool mlist_targeting;
bool msg_condense_repeats;
bool msg_condense_short;
@@ -176,7 +176,7 @@ public:
chunk_drop_type auto_drop_chunks; // drop chunks when overburdened
bool easy_eat_chunks; // make 'e' auto-eat the oldest safe chunk
bool auto_eat_chunks; // allow eating chunks while resting or travelling
- bool default_target; // start targetting on a real target
+ bool default_target; // start targeting on a real target
bool autopickup_no_burden; // don't autopickup if it changes burden
skill_focus_mode skill_focus; // is the focus skills available
@@ -193,7 +193,7 @@ public:
int colour[16]; // macro fg colours to other colours
int background_colour; // select default background colour
msg_colour_type channels[NUM_MESSAGE_CHANNELS]; // msg channel colouring
- bool darken_beyond_range; // for whether targetting is out of range
+ bool darken_beyond_range; // for whether targeting is out of range
int hp_warning; // percentage hp for danger warning
int magic_point_warning; // percentage mp for danger warning